<?php
/**
 * Easily manage navigation with Kahanit Awe Menu
 *
 * Kahanit Awe Menu by Kahanit(http://www.kahanit.com) is licensed under a
 * Creative Creative Commons Attribution-NoDerivatives 4.0 International License.
 * Based on a work at http://www.kahanit.com.
 * Permissions beyond the scope of this license may be available at http://www.kahanit.com.
 * To view a copy of this license, visit http://creativecommons.org/licenses/by-nd/4.0/.
 *
 * @author    Amit Sidhpura <amit@kahanit.com>
 * @copyright 2015 Kahanit
 * @license   http://creativecommons.org/licenses/by-nd/4.0/
 */

require_once _PS_MODULE_DIR_.'massmanagement/config/define.php';
include_once _MODULE_MM_DIR_.'libraries/Kahanit/Helpers.php';

/**
 * Class AMMenu
 */
class AdminMMCategoriesController extends ModuleAdminController
{
    public function init()
    {
        parent::init();

        $shop_list = Shop::getContextListShopID();
        $redirect = false;

        if (count($shop_list) == 1) {
            $default_shop = $this->context->shop->id;
        } else {
            $default_shop = current($shop_list);
            $redirect = true;
        }

        if ($redirect) {
            $controller = 'AdminMMCategories';
            $id_lang = $this->context->language->id;
            $params = array(
                'token' => Tools::getAdminTokenLite($controller),
                'setShopContext' => 's-'.$default_shop
            );

            $link = Dispatcher::getInstance()->createUrl($controller, $id_lang, $params, false);
            Tools::redirectAdmin($link);
            die();
        }

        $this->bootstrap = true;
    }

    public function setMedia()
    {
        parent::setMedia();

        // Styles
        $this->addCSS(_MODULE_MM_URI_.'views/css/dataTables.bootstrap.css');
        $this->addCSS(_MODULE_MM_URI_.'views/css/jquery-ui.min.css');
        $this->addCSS(_MODULE_MM_URI_.'views/css/ui.fancytree.css');
        $this->addCSS(_MODULE_MM_URI_.'views/css/common.css');

        // Scripts
        $this->addJquery();
        $this->addJqueryPlugin('chosen');
        $this->addJS(_MODULE_MM_URI_.'views/js/jquery.dataTables.min.js');
        $this->addJS(_MODULE_MM_URI_.'views/js/dataTables.bootstrap.js');
        $this->addJS(_MODULE_MM_URI_.'views/js/jquery-ui.min.js');
        $this->addJS(_MODULE_MM_URI_.'views/js/jquery.fancytree.js');
        $this->addJS(_MODULE_MM_URI_.'views/js/jquery.fancytree.dnd.js');
        $this->addJS(_MODULE_MM_URI_.'views/js/jquery.fancytree.edit.js');
        $this->addJS(_MODULE_MM_URI_.'views/js/jquery.fancytree.table.js');
        $this->addJS(_MODULE_MM_URI_.'views/js/category.js');
        $this->addJS(_MODULE_MM_URI_.'views/js/common.js');
    }

    public function initContent()
    {
        parent::initContent();

        $method = Tools::getValue('method', 'names');

        $lang_data = array();
        $langs = Language::getLanguages();

        foreach ($langs as $lang) {
            $lang_data[$lang['id_lang']] = Language::getLanguage($lang['id_lang']);
        }

        $shop_context = $this->context->cookie->shopContext;

        if (preg_match('/s-\d+/', $shop_context)) {
            $default_shop = $this->context->shop->id;
        } elseif (preg_match('/g-\d+/', $shop_context)) {
            $group_id = str_replace('g-', '', $shop_context);
            $shops = ShopGroup::getShopsFromGroup($group_id);
            $default_shop = array();

            foreach ($shops as $shop) {
                $default_shop[] = $shop['id_shop'];
            }

            $default_shop = implode(',', $default_shop);
        } else {
            $default_shop = '';
        }

        $this->context->smarty->assign(array(
            'module_name' => $this->module->name,
            'module_display_name' => $this->module->displayName,
            'module_version' => $this->module->version,
            // for massmanagement variables
            'default_language' => $this->context->language->id,
            'default_shop' => $default_shop,
            'lang_data' => Tools::jsonEncode($lang_data)
        ));

        $this->setTemplate($method.'.tpl');
    }

    public function displayAjax()
    {
        if (Tools::getValue('app', false)) {
            $url = explode('/', filter_var(rtrim(Tools::getValue('app'), ' / '), FILTER_SANITIZE_URL));

            if (isset($url[0])) {
                //$module_name = $url[0];
                unset($url[0]);
            }

            if (isset($url[1])) {
                //$controller_name = $url[1];
                unset($url[1]);
            }

            if (isset($url[2])) {
                $method_name = $url[2];
                unset($url[2]);
            }

            $url = array_values($url);
            $params = array();

            foreach ($url as $key => $value) {
                if ($key % 2 == 0) {
                    $params[$value] = $url[$key + 1];
                }
            }

            if (isset($method_name) && !empty($method_name) && method_exists($this, $method_name)) {
                echo $this->$method_name($params);
                die();
            }
        }
    }

    public function hookDisplayBackOfficeHeader()
    {
        // Styles
        $this->context->controller->addCSS($this->_path.'public/css/jquery-ui.min.css');
        $this->context->controller->addCSS($this->_path.'public/css/ui.fancytree.css');

        // Scripts
        $this->context->controller->addJqueryPlugin('chosen');
        $this->context->controller->addJS($this->_path.'public/js/jquery-ui.min.js');
        $this->context->controller->addJS($this->_path.'public/js/jquery.fancytree.js');
        $this->context->controller->addJS($this->_path.'public/js/jquery.fancytree.dnd.js');
        $this->context->controller->addJS($this->_path.'public/js/jquery.fancytree.edit.js');
        $this->context->controller->addJS($this->_path.'public/js/jquery.fancytree.table.js');
        $this->context->controller->addJS($this->_path.'public/js/category.js');
    }

    public function ajaxPopulateTreeTable()
    {
        $id_category_parent = (int)Tools::getValue('key', 0);
        $search = trim(Tools::getValue('search', ''));

        $langs = Language::getLanguages();
        $lang_id = (int)Tools::getValue('id_lang', $this->context->language->id);
        $shop_id = Tools::getValue('id_shop', null);

        if ($id_category_parent == 0) {
            $id_category_parent = Category::getRootCategory()->id_parent;
        }

        KIHelpers::getLibrary('Kahanit/Categories', $this->module);
        $categories = KICategories::getCategories($lang_id, $id_category_parent, $search, $shop_id);

        $data = array();
        $c = 0;

        foreach ($categories as $category) {
            $data[$c] = array();
            $data[$c]['key'] = $category['id_category'];
            $data[$c]['folder'] = true;

            if ($search == '') {
                $var_bool = (bool)KICategories::getChildrenCount($category['id_category']);

                $data[$c]['expanded'] = !$var_bool;
                $data[$c]['lazy'] = $var_bool;
            } else {
                $data[$c]['expanded'] = true;
                $data[$c]['lazy'] = false;
            }

            foreach ($langs as $lang) {
                $category_lang = new Category($category['id_category'], $lang['id_lang']);

                if ($lang_id == $lang['id_lang']) {
                    $data[$c]['title'] = $category_lang->name;
                }

                $data[$c]['name'][$lang['id_lang']] = $category_lang->name;
                $data[$c]['meta_title'][$lang['id_lang']] = $category_lang->meta_title;
                $data[$c]['meta_description'][$lang['id_lang']] = $category_lang->meta_description;
                $data[$c]['meta_keywords'][$lang['id_lang']] = $category_lang->meta_keywords;
                $data[$c]['link_rewrite'][$lang['id_lang']] = $category_lang->link_rewrite;
            }

            $data[$c] = (object)$data[$c];
            $c++;
        }

        return Tools::jsonEncode($data);
    }

    public function getCurrentLanguageButton($id_lang)
    {
        $langs = Language::getLanguages();
        $tmp_lang = '';
        $htm = '';
        foreach ($langs as $lang) {
            if ($lang['id_lang'] == $id_lang) {
                $tmp_lang = '
	                <div class="col-lg-12">
	                    <button type="button" class="btn btn-default dropdown-toggle" tabindex="-1" data-toggle="dropdown">
	                    	'.$lang['iso_code'].'&nbsp;&nbsp;<i class="icon-caret-down"></i>
	                    </button>
	                <ul class="dropdown-menu">';
            }
            $htm .= '<li>
				<a href="javascript:mmHideOtherLanguage('.$lang['id_lang'].');" tabindex="-1"
				rollapp-href="javascript:mmHideOtherLanguage('.$lang['id_lang'].');">'.$lang['name'].'</a>
			</li>';
        }
        $htm .= '</ul></div>';

        return $tmp_lang.$htm;
    }

    public function moveCategory($id_parent, $id_child)
    {
        $query = 'UPDATE `'._DB_PREFIX_.'category` SET `id_parent` = '.(int)$id_parent.' WHERE `id_category` = '.(int)$id_child;
        $res = Db::getInstance()->execute($query);

        return (bool)$res;
    }

    public function updateCategoryPosition($pos_to_id_array = array())
    {
        foreach ($pos_to_id_array as $node) {
            $query = 'UPDATE `'._DB_PREFIX_.'category_shop` SET `position` = '.(int)$node[0].'
			WHERE `id_category` = '.(int)$node[1].' AND `id_shop`='.(int)$this->context->shop->id;
            Db::getInstance()->execute($query);

            $query = 'UPDATE `'._DB_PREFIX_.'category` SET `id_parent` = '.(int)$node[2].'
			WHERE `id_category` = '.(int)$node[1];
            Db::getInstance()->execute($query);
        }
    }

    public function moveCopyProducts($ids = '', $id_category, $action, $id_category_source)
    {
        $id_array = explode(',', $ids);
        if ($action == 'move') {
            $pos = 1;
            foreach ($id_array as $id_product) {
                Db::getInstance()->execute('
        			UPDATE IGNORE `'._DB_PREFIX_.'category_product` SET `id_category` = '.(int)$id_category.'
                    WHERE `id_product` = '.(int)$id_product.'
                    AND `id_category` = '.(int)$id_category_source
                );
                Db::getInstance()->execute('
        			DELETE FROM `'._DB_PREFIX_.'category_product`
                    WHERE `id_product` = '.(int)$id_product.'
                    AND `id_category` = '.(int)$id_category_source
                );

                /* assign default category */
                $product = new Product($id_product);
                $id_category_default = $product->id_category_default;
                $product_categories = $product->getCategories();
                if (!in_array($id_category_default, $product_categories)) {
                    $product->id_category_default = $id_category;
                    $product->save();
                }

                $pos++;
            }

            return $pos;
        } else {
            if ($action == 'copy') {
                $pos = 1;
                foreach ($id_array as $id_product) {
                    Db::getInstance()->execute('
        			INSERT IGNORE INTO `'._DB_PREFIX_.'category_product` (`id_product`, `id_category`, `position`)
        			VALUES ('.(int)$id_product.','.(int)$id_category.','.(int)$pos.')'
                    );
                    $pos++;
                }

                return $pos;
            }
        }

        return false;
    }

    public function ajaxUpdateMetaField()
    {
        $field = Tools::getValue('metafield');
        $id_lang = Tools::getValue('lang_id');
        $id_category = Tools::getValue('id_category');
        $metavalue = Tools::getValue('metavalue');
        echo $this->updateMetaField($field, $metavalue, $id_category, $id_lang);
    }

    public function updateMetaField($field, $metavalue, $id_category, $id_lang)
    {
        $flag = Db::getInstance()->execute('
			UPDATE `'._DB_PREFIX_.'category_lang` SET `'.bqSQL($field).'` = \''.pSQL($metavalue).'\'
			WHERE `id_category` = '.(int)$id_category.' AND `id_lang` ='.(int)$id_lang
        );

        return $flag;
    }

    public function ajaxMovecategory()
    {
        if (Tools::getValue('hitMode') == 'over') {
            $id_parent = (int)Tools::getValue('id_parent');
            $id_child = (int)Tools::getValue('id_child');

            return $this->moveCategory($id_parent, $id_child);
        } else {
            if (Tools::getValue('hitMode') == 'after' || Tools::getValue('hitMode') == 'before') {
                $this->updateCategoryPosition(Tools::getValue('keyToposition', array()));
            }
        }
    }

    public function ajaxMoveCopyProducts()
    {
        $ids = (string)Tools::getValue('ids');
        $id_category = (int)Tools::getValue('id_category');
        $action = (string)Tools::getValue('action');
        $id_category_source = (int)Tools::getValue('id_category_source');
        echo $this->moveCopyProducts($ids, $id_category, $action, $id_category_source);
    }
}