<?php
/**
 * Easily manage navigation with Kahanit Awe Menu
 *
 * Kahanit Awe Menu by Kahanit(http://www.kahanit.com) is licensed under a
 * Creative Creative Commons Attribution-NoDerivatives 4.0 International License.
 * Based on a work at http://www.kahanit.com.
 * Permissions beyond the scope of this license may be available at http://www.kahanit.com.
 * To view a copy of this license, visit http://creativecommons.org/licenses/by-nd/4.0/.
 *
 * @author    Amit Sidhpura <amit@kahanit.com>
 * @copyright 2015 Kahanit
 * @license   http://creativecommons.org/licenses/by-nd/4.0/
 */

require_once _PS_MODULE_DIR_.'massmanagement/config/define.php';
include_once _MODULE_MM_DIR_.'libraries/Kahanit/Helpers.php';

/**
 * Class AMMenu
 */
class AdminMMCustomersController extends ModuleAdminController
{
    public $action;

    public $tag;

    public $id_customer;

    public function init()
    {
        parent::init();

        $shop_list = Shop::getContextListShopID();
        $redirect = false;

        if (count($shop_list) == 1) {
            $default_shop = $this->context->shop->id;
        } else {
            $default_shop = current($shop_list);
            $redirect = true;
        }

        if ($redirect) {
            $controller = 'AdminMMCustomers';
            $id_lang = $this->context->language->id;
            $params = array(
                'token' => Tools::getAdminTokenLite($controller),
                'setShopContext' => 's-'.$default_shop
            );

            $link = Dispatcher::getInstance()->createUrl($controller, $id_lang, $params, false);
            Tools::redirectAdmin($link);
            die();
        }

        $this->bootstrap = true;
    }

    public function setMedia()
    {
        parent::setMedia();

        // Styles
        $this->addCSS(_MODULE_MM_URI_.'views/css/dataTables.bootstrap.css');
        $this->addCSS(_MODULE_MM_URI_.'views/css/bootstrap-tagsinput.css');
        $this->addCSS(_MODULE_MM_URI_.'views/css/common.css');

        // Scripts
        $this->addJquery();
        $this->addJqueryPlugin('chosen');
        $this->addJS(_MODULE_MM_URI_.'views/js/jquery.dataTables.min.js');
        $this->addJS(_MODULE_MM_URI_.'views/js/dataTables.bootstrap.js');
        $this->addJS(_MODULE_MM_URI_.'views/js/typeahead.bundle.min.js');
        $this->addJS(_MODULE_MM_URI_.'views/js/bootstrap-tagsinput.min.js');
        $this->addJS(_MODULE_MM_URI_.'views/js/customer.js');
        $this->addJS(_MODULE_MM_URI_.'views/js/common.js');


        /* $this->addCSS(_MODULE_AM_URI_.'/views/css/bootstrap.css'); */

        $this->addJquery();
        /* $this->addJS(_MODULE_AM_URI_.'/views/js/jquery.awemenu.loader.js'); */
    }

    public function initContent()
    {
        parent::initContent();

        $method = Tools::getValue('method', 'name');

        $lang_data = array();
        $langs = Language::getLanguages();

        foreach ($langs as $lang) {
            $lang_data[$lang['id_lang']] = Language::getLanguage($lang['id_lang']);
        }

        $shop_context = $this->context->cookie->shopContext;

        if (preg_match('/s-\d+/', $shop_context)) {
            $default_shop = $this->context->shop->id;
        } elseif (preg_match('/g-\d+/', $shop_context)) {
            $group_id = str_replace('g-', '', $shop_context);
            $shops = ShopGroup::getShopsFromGroup($group_id);
            $default_shop = array();

            foreach ($shops as $shop) {
                $default_shop[] = $shop['id_shop'];
            }

            $default_shop = implode(',', $default_shop);
        } else {
            $default_shop = '';
        }

        $this->context->smarty->assign(array(
            'module_name' => $this->module->name,
            'module_display_name' => $this->module->displayName,
            'module_version' => $this->module->version,
            // for massmanagement variables
            'default_language' => $this->context->language->id,
            'default_shop' => $default_shop,
            'lang_data' => Tools::jsonEncode($lang_data)
        ));

        $this->setTemplate($method.'.tpl');
    }

    public function displayAjax()
    {
        if (Tools::getValue('app', false)) {
            $url = explode('/', filter_var(rtrim(Tools::getValue('app'), ' / '), FILTER_SANITIZE_URL));

            if (isset($url[0])) {
                //$module_name = $url[0];
                unset($url[0]);
            }

            if (isset($url[1])) {
                //$controller_name = $url[1];
                unset($url[1]);
            }

            if (isset($url[2])) {
                $method_name = $url[2];
                unset($url[2]);
            }

            $url = array_values($url);
            $params = array();

            foreach ($url as $key => $value) {
                if ($key % 2 == 0) {
                    $params[$value] = $url[$key + 1];
                }
            }

            if (isset($method_name) && !empty($method_name) && method_exists($this, $method_name)) {
                echo $this->$method_name($params);
                die();
            }
        }
    }

    public function populateCustomersToDT()
    {
        $order = Tools::getValue('order', array(array('column' => 0, 'dir' => 'ASC')));
        $columns = Tools::getValue('columns', array());

        $start = (int)Tools::getValue('start', 0);
        $length = (int)Tools::getValue('length', 25);
        $search_get = Tools::getValue('search', array('value' => ''));
        $search = $search_get['value'];

        $orderfld = Tools::strtolower($columns[$order[0]['column']]['data']);
        $orderdir = Tools::strtoupper($order[0]['dir']);

        $shop_id = Tools::getValue('id_shop', null);

        KIHelpers::getLibrary('Kahanit/Customers', $this->module);
        $customers = KICustomers::getCustomers($search, $start, $length, $orderfld, $orderdir, $shop_id);
        $customers_total = KICustomers::getNumCustomers($search, $shop_id);

        $data = array();
        $c = 0;

        foreach ($customers as $customer) {
            $data[$c] = array();
            $data[$c]['id'] = $customer['id_customer'];
            $data[$c]['id_customer'] = $customer['id_customer'];
            $data[$c]['firstname'] = $customer['firstname'];
            $data[$c]['lastname'] = $customer['lastname'];
            $data[$c]['email'] = $customer['email'];
            $data[$c]['group'] = $this->getGroupNames($customer['id_customer']);

            $data[$c] = (object)$data[$c];
            $c++;
        }

        return Tools::jsonEncode(array(
            'recordsTotal' => $customers_total,
            'recordsFiltered' => $customers_total,
            'data' => $data
        ));
    }

    public function getAllCustomers()
    {
        $order = Tools::getValue('order', array());
        $columns = Tools::getValue('columns', array());
        $order_way = Tools::strtoupper($order[0]['dir']);
        $order_field = Tools::strtolower($columns[$order[0]['column']]['data']);
        $sql = 'SELECT `id_customer`, `email`, `firstname`, `lastname`
				FROM `'._DB_PREFIX_.'customer`
				WHERE 1 '.Shop::addSqlRestriction(Shop::SHARE_CUSTOMER).'
				ORDER BY `'.bqSQL($order_field).'` '.bqSQL($order_way);

        return Db::getInstance(_PS_USE_SQL_SLAVE_)->executeS($sql);
    }

    public function getGroupNames($id_cusomer)
    {
        $groups = array();
        $rows = Db::getInstance(_PS_USE_SQL_SLAVE_)->executeS('
            SELECT cg.`id_group`, gl.`name` FROM `'._DB_PREFIX_.'customer_group` cg
            LEFT JOIN `'._DB_PREFIX_.'customer` c ON (c.`id_customer` = cg.`id_customer`)
            LEFT JOIN `'._DB_PREFIX_.'group` g ON (g.`id_group` = cg.`id_group`)
            LEFT JOIN `'._DB_PREFIX_.'group_lang` gl ON (gl.`id_group` = g.`id_group`)
            WHERE gl.`id_lang`=1
            AND c.`id_customer`='.(int)$id_cusomer
        );

        foreach ($rows as $row) {
            $groups[] = $row['name'];
        }

        return implode(',', $groups);
    }

    public function getAllGroups()
    {
        $groups = array();
        $rows = Db::getInstance(_PS_USE_SQL_SLAVE_)->executeS('
			 SELECT * FROM `'._DB_PREFIX_.'group_lang` gl
			 LEFT JOIN `'._DB_PREFIX_.'group` g ON (g.`id_group` = gl.`id_group`)
			 WHERE gl.`id_lang` ='.(int)Context::getContext()->language->id
        );

        foreach ($rows as $row) {
            $groups[] = $row['name'];
        }

        return Tools::jsonEncode($groups);
    }

    public function manageGroupToCustomer($action, $tag, $id_customer)
    {
        $customer = new Customer($id_customer);
        if ($action) {
            return $customer->addGroups(array($this->getGroupIdByName($tag)));
        } else {
            $flag = Db::getInstance()->execute('
				DELETE FROM `'._DB_PREFIX_.'customer_group`
				WHERE `id_customer` = '.(int)$id_customer.' AND `id_group` ='.(int)$this->getGroupIdByName($tag)
            );

            return $flag;
        }
    }

    public function ajaxManageGroupToCustomer()
    {
        echo $this->manageGroupToCustomer((int)Tools::getValue('tagAction'),
            (string)Tools::getValue('tag'), Tools::getValue('id_customer'));
    }

    public function getGroupIdByName($name)
    {
        $sql = 'SELECT `id_group` FROM `'._DB_PREFIX_.'group_lang`
			WHERE `name` =\''.pSQL($name).'\' AND `id_lang` = '.(int)Context::getContext()->language->id;
        $rows = Db::getInstance(_PS_USE_SQL_SLAVE_)->executeS($sql);

        if (count($rows)) {
            return (int)$rows[0]['id_group'];
        }

        return -1;
    }

    public function ajaxGetAllCustomers()
    {
        $data = array();
        $customers = $this->getAllCustomers();
        $data['recordsTotal'] = count($customers);
        $counter = 0;
        $i = 0;
        $start = (int)Tools::getValue('start');
        $length = $start + (int)Tools::getValue('length');

        foreach ($customers as $customer) {
            if ($i >= $start && $i <= $length) {
                $data['data'][$counter]['id_customer'] = $customer['id_customer'];
                $data['data'][$counter]['firstname'] = $customer['firstname'].' '.$customer['lastname'];
                $data['data'][$counter]['email'] = $customer['email'];
                $data['data'][$counter]['group'] = $this->getGroupNames($customer['id_customer']);
                $counter++;
            }
            $i++;
        }

        $data['recordsFiltered'] = $data['recordsTotal'];
        echo Tools::jsonEncode($data);
        die();
    }
}