<?php
/**
 * Easily manage navigation with Kahanit Awe Menu
 *
 * Kahanit Awe Menu by Kahanit(http://www.kahanit.com) is licensed under a
 * Creative Creative Commons Attribution-NoDerivatives 4.0 International License.
 * Based on a work at http://www.kahanit.com.
 * Permissions beyond the scope of this license may be available at http://www.kahanit.com.
 * To view a copy of this license, visit http://creativecommons.org/licenses/by-nd/4.0/.
 *
 * @author    Amit Sidhpura <amit@kahanit.com>
 * @copyright 2015 Kahanit
 * @license   http://creativecommons.org/licenses/by-nd/4.0/
 */

require_once _PS_MODULE_DIR_.'massmanagement/config/define.php';
include_once _MODULE_MM_DIR_.'libraries/Kahanit/Helpers.php';

/**
 * Class AMMenu
 */
class AdminMMProductsController extends ModuleAdminController
{
    public function init()
    {
        parent::init();

        $shop_list = Shop::getContextListShopID();
        $redirect = false;

        if (count($shop_list) == 1) {
            $default_shop = $this->context->shop->id;
        } else {
            $default_shop = current($shop_list);
            $redirect = true;
        }

        if ($redirect) {
            $controller = 'AdminMMProducts';
            $id_lang = $this->context->language->id;
            $params = array(
                'token' => Tools::getAdminTokenLite($controller),
                'setShopContext' => 's-'.$default_shop
            );

            $link = Dispatcher::getInstance()->createUrl($controller, $id_lang, $params, false);
            Tools::redirectAdmin($link);
            die();
        }

        $this->bootstrap = true;
    }

    public function setMedia()
    {
        parent::setMedia();

        // Styles
        $this->addCSS(_MODULE_MM_URI_.'views/css/dataTables.bootstrap.css');
        $this->addCSS(_MODULE_MM_URI_.'views/css/bootstrap-tagsinput.css');
        $this->addCSS(_MODULE_MM_URI_.'views/css/common.css');

        // Scripts
        $this->addJquery();
        $this->addJqueryPlugin('chosen');
        $this->addJS(_MODULE_MM_URI_.'views/js/jquery.dataTables.min.js');
        $this->addJS(_MODULE_MM_URI_.'views/js/dataTables.bootstrap.js');
        $this->addJS(_MODULE_MM_URI_.'views/js/typeahead.bundle.min.js');
        $this->addJS(_MODULE_MM_URI_.'views/js/bootstrap-tagsinput.min.js');
        $this->addJS(_MODULE_MM_URI_.'views/js/product.js');
        $this->addJS(_MODULE_MM_URI_.'views/js/common.js');
    }

    public function initContent()
    {
        parent::initContent();

        $method = Tools::getValue('method', 'names');

        $lang_data = array();
        $langs = Language::getLanguages();

        foreach ($langs as $lang) {
            $lang_data[$lang['id_lang']] = Language::getLanguage($lang['id_lang']);
        }

        $shop_context = $this->context->cookie->shopContext;

        if (preg_match('/s-\d+/', $shop_context)) {
            $default_shop = $this->context->shop->id;
        } elseif (preg_match('/g-\d+/', $shop_context)) {
            $group_id = str_replace('g-', '', $shop_context);
            $shops = ShopGroup::getShopsFromGroup($group_id);
            $default_shop = array();

            foreach ($shops as $shop) {
                $default_shop[] = $shop['id_shop'];
            }

            $default_shop = implode(',', $default_shop);
        } else {
            $default_shop = '';
        }

        $this->context->smarty->assign(array(
            'module_name' => $this->module->name,
            'module_display_name' => $this->module->displayName,
            'module_version' => $this->module->version,
            // for massmanagement variables
            'default_language' => $this->context->language->id,
            'default_shop' => $default_shop,
            'lang_data' => Tools::jsonEncode($lang_data)
        ));

        $this->setTemplate($method.'.tpl');
    }

    public function displayAjax()
    {
        if (Tools::getValue('app', false)) {
            $url = explode('/', filter_var(rtrim(Tools::getValue('app'), ' / '), FILTER_SANITIZE_URL));

            if (isset($url[0])) {
                //$module_name = $url[0];
                unset($url[0]);
            }

            if (isset($url[1])) {
                //$controller_name = $url[1];
                unset($url[1]);
            }

            if (isset($url[2])) {
                $method_name = $url[2];
                unset($url[2]);
            }

            $url = array_values($url);
            $params = array();

            foreach ($url as $key => $value) {
                if ($key % 2 == 0) {
                    $params[$value] = $url[$key + 1];
                }
            }

            if (isset($method_name) && !empty($method_name) && method_exists($this, $method_name)) {
                echo $this->$method_name($params);
                die();
            }
        }
    }

    public function populateProductsToDT()
    {
        $order = Tools::getValue('order', array(array('column' => 0, 'dir' => 'ASC')));
        $columns = Tools::getValue('columns', array());

        $start = (int)Tools::getValue('start', 0);
        $length = (int)Tools::getValue('length', 25);
        $category_id = (int)Tools::getValue('id_category', null);
        $search_get = Tools::getValue('search', array('value' => ''));
        $search = $search_get['value'];

        $orderfld = Tools::strtolower($columns[$order[0]['column']]['data']);
        $orderdir = Tools::strtoupper($order[0]['dir']);

        $langs = Language::getLanguages();
        $lang_id = (int)Tools::getValue('id_lang', $this->context->language->id);
        $shop_id = Tools::getValue('id_shop', null);

        KIHelpers::getLibrary('Kahanit/Products', $this->module);
        $products = KIProducts::getProducts($lang_id, $category_id, $search, $start, $length, $orderfld,
            $orderdir, $shop_id);
        $products_total = KIProducts::getNumProducts($category_id, $search, $shop_id);

        $data = array();
        $c = 0;

        foreach ($products as $product) {
            $data[$c] = array();
            $data[$c]['id'] = $product['id_product'];
            $data[$c]['id_product'] = $product['id_product'];

            foreach ($langs as $lang) {
                $product_lang = new Product($product['id_product'], false, $lang['id_lang']);

                $data[$c]['name'][$lang['id_lang']] = $product_lang->name;
                $data[$c]['meta_title'][$lang['id_lang']] = $product_lang->meta_title;
                $data[$c]['meta_description'][$lang['id_lang']] = $product_lang->meta_description;
                $data[$c]['meta_keywords'][$lang['id_lang']] = $product_lang->meta_keywords;
                $data[$c]['link_rewrite'][$lang['id_lang']] = $product_lang->link_rewrite;
                $data[$c]['tags'][$lang['id_lang']] = $this->getProductTags($product['id_product'], $lang['id_lang']);
            }

            $data[$c]['suplierDD'] = $this->getAllSupplier($product['id_product'], 1);
            $data[$c]['suppliers'] = $this->getManufacturerByProductId($product['id_product']);
            $data[$c]['manufacturer'] = $this->getManufacturers($product_lang->id_manufacturer);

            $data[$c] = (object)$data[$c];
            $c++;
        }

        return Tools::jsonEncode(array(
            'recordsTotal' => $products_total,
            'recordsFiltered' => $products_total,
            'data' => $data
        ));
    }

    public function getManufacturers($set_selected)
    {
        $manufacturers = Manufacturer::getManufacturers();
        $options = '<option value="0">--</option>';

        foreach ($manufacturers as $manufacturer) {
            if ($manufacturer['id_manufacturer'] == $set_selected) {
                $options .= '<option value="'.$manufacturer['id_manufacturer'].'" selected="selected">'.$manufacturer['name'].'</option>';
            } else {
                $options .= '<option value="'.$manufacturer['id_manufacturer'].'">'.$manufacturer['name'].'</option>';
            }
        }

        return $options;
    }

    public function getProductTags($id_product, $id_lang)
    {
        if (!$tmp = Db::getInstance(_PS_USE_SQL_SLAVE_)->executeS(
            'SELECT t.`id_lang`, t.`name`
			FROM '._DB_PREFIX_.'tag t
			LEFT JOIN '._DB_PREFIX_.'product_tag pt ON (pt.id_tag = t.id_tag)
			WHERE pt.`id_product`='.(int)$id_product)
        ) {
            return '';
        }

        $result = array();

        foreach ($tmp as $tag) {
            if ($tag['id_lang'] == $id_lang) {
                $result[] = $tag['name'];
            }
        }

        if ($result) {
            return implode(',', $result);
        }

        return null;
    }

    public function ajaxUpdateMetaField()
    {
        $field = Tools::getValue('productmetafield');
        $id_lang = Tools::getValue('lang_id');
        $id_product = Tools::getValue('id_product');
        $metavalue = Tools::getValue('metavalue');
        echo $this->updateProductMetaField($field, $metavalue, $id_product, $id_lang);
    }

    public function updateProductMetaField($field, $metavalue, $id_product, $id_lang)
    {
        $flag = Db::getInstance()->execute(
            'UPDATE `'._DB_PREFIX_.'product_lang` SET `'.bqSQL($field).'` = \''.pSQL($metavalue).'\'
			WHERE `id_product` = '.(int)$id_product.' AND `id_lang` ='.(int)$id_lang
        );

        return $flag;
    }

    public function ajaxUpdateManufacturer()
    {
        echo $this->updateManufacturer((int)Tools::getValue('id_product'), (int)Tools::getValue('id_manufacturer'));
    }

    public function updateManufacturer($id_product, $id_manufacturer)
    {
        $flag = Db::getInstance()->execute(
            'UPDATE `'._DB_PREFIX_.'product` SET `id_manufacturer` = '.(int)$id_manufacturer.'
			WHERE `id_product` = '.(int)$id_product
        );

        return $flag;
    }

    public function ajaxAddRemoveProductTag()
    {
        echo $this->addRemoveTag((int)Tools::getValue('productTagAction'),
            (int)Tools::getValue('lang_id'), (int)Tools::getValue('id_product'), (string)Tools::getValue('tag'));
    }

    public function addRemoveTag($action, $id_lang, $id_product, $tag)
    {
        if ($action) {
            return Tag::addTags($id_lang, $id_product, $tag);
        } else {
            return Db::getInstance()->execute(
                'DELETE FROM `'._DB_PREFIX_.'product_tag`
				WHERE `id_product` = '.(int)$id_product.' AND `id_tag` =(SELECT `id_tag` FROM `'._DB_PREFIX_.'tag`
				WHERE `name` = \''.pSQL($tag).'\' AND `id_lang` ='.(int)$id_lang.')'
            );
        }
    }

    public function addRemoveProductSupplier()
    {
        $action = (int)Tools::getValue('productSupplierAction');
        $id_product = (int)Tools::getValue('id_product');
        $supplier = (string)Tools::getValue('supplier');
        $flag = 0;

        if ($action) {
            $flag = Db::getInstance()->execute(
                'INSERT IGNORE INTO `'._DB_PREFIX_.'product_supplier`(`id_product`,`id_product_attribute`,`id_supplier`,
				`product_supplier_reference`,`product_supplier_price_te`, `id_currency`)
				VALUES('.(int)$id_product.', 0,(SELECT `id_supplier`
				FROM `'._DB_PREFIX_.'supplier`
				WHERE `name`=\''.pSQL($supplier).'\'),\'\',0.00,'.(int)Context::getContext()->currency->id.')'
            );
        } else {
            $flag = Db::getInstance()->execute(
                'DELETE FROM `'._DB_PREFIX_.'product_supplier`
				WHERE `id_product` = '.(int)$id_product.' AND `id_supplier`=(
				SELECT `id_supplier`
				FROM `'._DB_PREFIX_.'supplier`
				WHERE `name`=\''.pSQL($supplier).'\')'
            );
        }

        return $flag;
    }

    public function getAllSupplier($id_product = 0, $dropdown = 0)
    {
        $suppliers = array();
        $rows = Db::getInstance(_PS_USE_SQL_SLAVE_)->executeS(
            'SELECT * FROM `'._DB_PREFIX_.'supplier`'
        );

        if ($dropdown && $id_product) {
            $default_supplier = Db::getInstance(_PS_USE_SQL_SLAVE_)->getValue(
                'SELECT `id_supplier`
				FROM `'._DB_PREFIX_.'product`
				WHERE `id_product` = '.(int)$id_product
            );

            $dropdown_html = '<option value="0" selected="selected"> -- </option>';

            foreach ($rows as $row) {
                if ($default_supplier == $row['id_supplier']) {
                    $dropdown_html .= '<option value="'.$row['id_supplier'].'" selected="selected">'.$row['name'].'</option>';
                } else {
                    $dropdown_html .= '<option value="'.$row['id_supplier'].'">'.$row['name'].'</option>';
                }
            }

            return $dropdown_html;
        }

        foreach ($rows as $row) {
            $suppliers[] = $row['name'];
        }

        return Tools::jsonEncode($suppliers);
    }

    public function getManufacturerByProductId($id_product)
    {
        $rows = Db::getInstance(_PS_USE_SQL_SLAVE_)->executeS(
            'SELECT DISTINCT s.`id_supplier`, s.`name`
			FROM `'._DB_PREFIX_.'product` p
			LEFT JOIN `'._DB_PREFIX_.'product_supplier` ps ON(p.`id_product`=ps.`id_product`)
			LEFT JOIN `'._DB_PREFIX_.'supplier` s ON(ps.`id_supplier`=s.`id_supplier`)
			WHERE p.`id_product`='.(int)$id_product
        );

        $sup = '';

        foreach ($rows as $row) {
            $sup .= $row['name'].',';
        }

        return Tools::substr($sup, 0, Tools::strlen($sup) - 1);
    }

    public function updateDefaultSupplier()
    {
        $flag = Db::getInstance()->execute(
            'UPDATE `'._DB_PREFIX_.'product` SET `id_supplier` = '.(int)Tools::getValue('id_supplier', 0).'
			WHERE `id_product` = '.(int)Tools::getValue('id_product', 0)
        );

        return $flag;
    }
}