<?php
/**
 * Mass/Bulk update products, categories and customers
 *
 * Mass Management - PrestaShop Mass Edit Module by Kahanit(http://www.kahanit.com)
 * is licensed under a Creative Creative Commons Attribution-NoDerivatives 4.0
 * International License. Based on a work at http://www.kahanit.com.
 * Permissions beyond the scope of this license may be available at http://www.kahanit.com.
 * To view a copy of this license, visit http://creativecommons.org/licenses/by-nd/4.0/.
 *
 * @author    Amit Sidhpura <amit@kahanit.com>
 * @copyright 2015 Kahanit
 * @license   http://creativecommons.org/licenses/by-nd/4.0/
 */

if (!defined('_PS_VERSION_')) {
    exit;
}

/**
 * Class MassManagement
 */
class MassManagement extends Module
{
    protected $route;

    public function __construct()
    {
        $this->name = 'massmanagement';
        $this->tab = 'quick_bulk_update';
        $this->version = '2.0.2';
        $this->author = 'Kahanit';
        $this->need_instance = 0;
        $this->module_key = '851462b657462e74e9a585544f871946';

        parent::__construct();

        $this->displayName = $this->l('Mass Management - PrestaShop Mass Edit Module');
        $this->description = $this->l('It provides intuitive and simple interfaces by which mass products, categories and customers update is very quick.');
        $this->confirmUninstall = $this->l('Are you sure?');
    }

    public function install()
    {
        return parent::install()
        && $this->installModuleTab('AdminMMProducts', 'Mass Management', 17)
        && $this->installModuleTab('AdminMMCategories', 'Mass Management', 17, false)
        && $this->installModuleTab('AdminMMCustomers', 'Mass Management', 17, false);
    }

    public function uninstall()
    {
        return parent::uninstall()
        && $this->uninstallModuleTab('AdminMMProducts')
        && $this->uninstallModuleTab('AdminMMCategories')
        && $this->uninstallModuleTab('AdminMMCustomers');
    }

    private function installModuleTab($tabClass, $tabName, $idTabParent, $showTab = true)
    {
        $tab = new Tab();

        foreach (Language::getLanguages() as $language) {
            $tab->name[$language['id_lang']] = pSQL($tabName);
        }

        $tab->class_name = pSQL($tabClass);
        $tab->module = pSQL($this->name);
        $tab->id_parent = (int)$idTabParent;
        $tab->active = (int)$showTab;

        if (!$tab->save()) {
            return false;
        }

        return true;
    }

    private function uninstallModuleTab($tabClass)
    {
        $idTab = Tab::getIdFromClassName($tabClass);

        if ($idTab != 0) {
            $tab = new Tab($idTab);
            $tab->delete();

            return true;
        }

        return false;
    }

    public function getContent()
    {
        $link = $this->context->link->getAdminLink('AdminMMProducts');
        Tools::redirectAdmin($link);
        die();
    }
}