/**
 * Mass/Bulk update products, categories and customers
 *
 * Mass Management - PrestaShop Mass Edit Module by Kahanit(http://www.kahanit.com)
 * is licensed under a Creative Creative Commons Attribution-NoDerivatives 4.0
 * International License. Based on a work at http://www.kahanit.com.
 * Permissions beyond the scope of this license may be available at http://www.kahanit.com.
 * To view a copy of this license, visit http://creativecommons.org/licenses/by-nd/4.0/.
 *
 * @author    Amit Sidhpura <amit@kahanit.com>
 * @copyright 2015 Kahanit
 * @license   http://creativecommons.org/licenses/by-nd/4.0/
 */

$(function () {
    var ajaxURL = mm_categories_url + '&id_lang=' + default_language + '&id_shop=' + default_shop;

    var ajaxURLProducts = mm_products_url + '&id_lang=' + default_language + '&id_shop=' + default_shop;

    var ids = '';

    var activate_node = true;

    var id_category_source = null;

    var id_category_destination = null;

    var action = '';

    var dialog = '';

    var productTable = null;

    var enableDragDrop = true;

    var displayLength = parseInt($('#product_length').val());
    displayLength = isNaN(displayLength) ? 25 : displayLength;

    $("#move_products_dialog, #copy_products_dialog").dialog({
        autoOpen: false,
        modal: true,
        appendTo: '#kahanit-mass-management',
        resizable: false,
        buttons: {
            "Confirm": function () {
                activate_node = false;
                $(this).dialog("close");
            },
            Cancel: function () {
                activate_node = true;
                $(this).dialog("close");
            }
        }
    });

    $("#noids_dialog").dialog({
        autoOpen: false,
        modal: true,
        appendTo: '#kahanit-mass-management',
        resizable: false,
        buttons: {
            "OK": function () {
                $(this).dialog("close");
            }
        }
    });

    $(".ui-dialog").find("button").addClass("btn btn-default");

    $(".ui-dialog-titlebar-close").append('<span class="icon-remove" aria-hidden="true"></span>').height('18');

    var categoryTree = $(".categoryTree").fancytree({
        extensions: ["dnd"],
        source: {
            url: ajaxURL + '&app=admin/categories/ajaxPopulateTreeTable',
            cache: false
        },
        init: function () {
            var firstChild = categoryTree.fancytree("getTree").getRootNode().getFirstChild();

            if (firstChild !== undefined)
                firstChild.setActive(true);
        },
        createNode: function (event, ctx) {
            if (!ctx.node.isStatusNode()) {
                var title = $("<div/>").html(ctx.node.title);
                title.find('span').remove();
                title = title.text();

                ctx.node.setTitle(title + ' <span class="nodeid">(ID:' + ctx.node.key + ')</span>');
            }
        },
        dnd: {
            autoExpandMS: 400,
            preventVoidMoves: true,
            preventRecursiveMoves: true,
            dragStart: function () {
                return enableDragDrop;
            },
            dragEnter: function () {
                return true;
            },
            dragDrop: function (node, data) {
                data.otherNode.moveTo(node, data.hitMode);
                var keyToposition = [];
                var i = 0;
                $(node.parent.children).each(function () {
                    var tmp = []
                    tmp.push(i + 1);
                    tmp.push($(this).attr('key'));
                    if (data.hitMode == 'after' || data.hitMode == 'before') {
                        tmp.push(data.node.parent.key);
                    }
                    else if (data.hitMode == 'over') {
                        tmp.push(data.node.key);
                    }
                    keyToposition.push(tmp);
                    i++;
                });
                var id_parent = data.node.key;
                var id_child = data.otherNode.key;
                $.ajax({
                    url: ajaxURL + '&app=admin/categories/ajaxMovecategory',
                    data: {
                        id_parent: id_parent,
                        id_child: id_child,
                        movecategory: 1,
                        keyToposition: keyToposition,
                        hitMode: data.hitMode
                    },
                    type: 'POST'
                }).success(function (data) {
                });
            }
        },
        beforeActivate: function (event, data) {
            id_category_destination = data.node.key;

            if (!activate_node) {
                moveCopyProducts();

                return false;
            }

            return true;
        },
        activate: function (event, data) {
            id_category_source = data.node.key;

            if (productTable == null)
                initProductTable(id_category_source);
            else
                productTable.api().ajax.url(
                    ajaxURLProducts + '&app=admin/products/populateProductsToDT&id_category=' + id_category_source
                ).load();
        },
        lazyLoad: function (event, data) {
            var node = data.node;
            data.result = {
                url: ajaxURL + '&app=admin/categories/ajaxPopulateTreeTable',
                cache: false,
                data: {key: node.key}
            }
        }
    });

    var categoryTreeTable = $(".categoryTreeTable").fancytree({
        extensions: ["table"],
        keyboard: false,
        table: {
            indentation: 20,
            nodeColumnIdx: 1
        },
        source: {
            url: ajaxURL + '&app=admin/categories/ajaxPopulateTreeTable'
        },
        lazyLoad: function (event, data) {
            var node = data.node;
            data.result = {
                url: ajaxURL + '&app=admin/categories/ajaxPopulateTreeTable',
                cache: false,
                data: {key: node.key}
            }
        },
        loadChildren: function (event, ctx) {
            if (ctx.node.isRoot() && ctx.node.countChildren() === 0)
                $('.categoryTreeTable tbody').html('<tr class="noresultfound">' +
                    '<td colspan="3">No data available in table</td>' +
                    '</tr>');
            else
                $('.categoryTreeTable tbody .noresultfound').remove();
        },
        renderColumns: function (event, data) {
            var entity = $(".categoryTreeTable").data('entity');
            var node = data.node;
            var $tdList = $(node.tr).find(">td");
            var lang_count = 0;

            $tdList.eq(0).text(node.key).addClass("alignRight");
            tmp_html = "";
            tmp_button = "";
            tmp_li = '';

            jQuery.each(lang_data, function (index) {
                tmp_li = tmp_li + '<li>\
					<a href="javascript:mmHideOtherLanguage(' + lang_data[index]['id_lang'] + ');" tabindex="-1"\
					rollapp-href="javascript:mmHideOtherLanguage(' + lang_data[index]['id_lang'] + ');">' + lang_data[index]['name'] + '</a>\
				</li>';
                lang_count = lang_count + 1;
            });

            tmp_li = tmp_li + '';

            jQuery.each((eval("node.data." + entity)), function (index, value) {
                if (lang_count > 1)
                    tmp_button = '<div class="col-lg-2">\
						<button type="button" class="btn btn-default dropdown-toggle" tabindex="-1" data-toggle="dropdown">\
						' + lang_data[index]['iso_code'] + '&nbsp; <span class="caret"></span>\
						</button>\
						<ul class="dropdown-menu">' + tmp_li + '</ul>\
					</div>';
                tmp_html = tmp_html + "<div class='row translatable-field lang-" + index + "'>\
					<div class='col-lg-10'><input type='text' id='category-metakey-" + index + "-" + node.key + "' \
					data-id_lang='" + index + "' data-metafield='" + entity + "'  class='form-control " + entity + "' \
					data-id_category='" + node.key + "' value='" + value + "'></div>" + tmp_button + "\
					</div>";
            });

            $tdList.eq(2).html(tmp_html).find("." + entity).on('change', updateCategoryMetaField);
            mmHideOtherLanguage(default_language);
        }
    });

    $("#move_products, #copy_products").on('click', function () {
        ids = prepareIDs();

        if (ids.length) {
            action = $(this).data('action');
            dialog = $(this).data('dialog');

            $(dialog).dialog("open");
        }
        else
            $("#noids_dialog").dialog('open');
    });

    $("#category_search").on('keyup', function (e) {
        if (e.keyCode == 13) {
            var searchtree;

            if ($('.categoryTree').length)
                searchtree = categoryTree;

            if ($('.categoryTreeTable').length)
                searchtree = categoryTreeTable;

            searchtree.fancytree('getTree').reload({
                url: ajaxURL + '&app=admin/categories/ajaxPopulateTreeTable&search=' + $("#category_search").val()
            });

            if ($("#category_search").val() == '')
                enableDragDrop = true;
            else
                enableDragDrop = false;
        }
    });

    $("#category_expandall").on('click', function () {
        var expandtree;

        if ($('.categoryTree').length)
            expandtree = categoryTree;

        if ($('.categoryTreeTable').length)
            expandtree = categoryTreeTable;

        expandtree.fancytree("getTree").visit(function (node) {
            node.setExpanded(true);
        });

        return false;
    });

    $("#category_collapseall").on('click', function () {
        var collapsetree;

        if ($('.categoryTree').length)
            collapsetree = categoryTree;

        if ($('.categoryTreeTable').length)
            collapsetree = categoryTreeTable;

        collapsetree.fancytree("getTree").visit(function (node) {
            node.setExpanded(false);
        });

        return false;
    });

    $('#category_reload').click(function () {
        var reloadtree;

        if ($('.categoryTree').length)
            reloadtree = categoryTree;

        if ($('.categoryTreeTable').length)
            reloadtree = categoryTreeTable;

        reloadtree.fancytree('getTree').reload({
            url: ajaxURL + '&app=admin/categories/ajaxPopulateTreeTable&search=' + $('#category_search').val()
        });

        return false;
    });

    $('#product_reload').click(function () {
        productTable.api().ajax.reload();
    });

    $('#product_length').keyup(function (e) {
        if (e.keyCode == 13) {
            var newLength = parseInt($('#product_length').val());
            newLength = isNaN(newLength) ? 25 : newLength;

            productTable.fnSettings()._iDisplayLength = newLength;
            productTable.fnDraw();
        }
    });

    $('#product_search').keyup(function (e) {
        if (e.keyCode == 13)
            productTable.fnFilter($(this).val());
    });

    function initProductTable(id_category) {
        productTable = $('.productTable').dataTable({
            "processing": true,
            "serverSide": true,
            "iDisplayLength": displayLength,
            "ajax": {
                "url": ajaxURLProducts + '&app=admin/products/populateProductsToDT&id_category=' + id_category
            },
            "columns": [
                {"data": "id_product", "width": "30px"},
                {"data": "name"}
            ],
            "pagingType": "full_numbers",
            "bLengthChange": false,
            "columnDefs": [
                {
                    "render": function (data, type, row) {
                        return row.name[default_language];
                    },
                    "targets": 1
                }
            ],
            "createdRow": function (row, data) {
                $(row).attr('data-productid', data.id).on('click', function () {
                    $(this).toggleClass('selected');
                });
            }
        });
    }

    function prepareIDs() {
        var rows = $('.productTable tbody tr.selected');
        var ids = '';

        $(rows).each(function () {
            ids = ids + $(this).data('productid') + ',';
        });

        return ids.substr(0, ids.length - 1);
    }

    function moveCopyProducts() {
        if (id_category_source == null || id_category_destination == null || action == '') {
            alert('Can not process');
            return;
        }

        $.ajax({
            url: ajaxURL + '&app=admin/categories/ajaxMoveCopyProducts',
            data: {
                ids: ids,
                action: action,
                id_category: id_category_destination,
                id_category_source: id_category_source
            },
            type: 'POST'
        }).success(function () {
            ids = '';
            activate_node = true;
            productTable.api().ajax.reload();

            /*id_category_source = null;
            id_category_destination = null;*/
        });
    }

    function updateCategoryMetaField() {
        var thisid = '#' + $(this).attr('id');
        var id_category = $(this).data('id_category');
        var id_lang = $(this).data('id_lang');
        var metafield = $(this).data('metafield');

        $(this).removeClass('kmmprocessdone').addClass('kmmprocess');

        $.ajax({
            url: ajaxURL + '&app=admin/categories/ajaxUpdateMetaField&flag=updatemetakey',
            type: 'POST',
            data: {lang_id: id_lang, id_category: id_category, metafield: metafield, metavalue: $(this).val()}
        }).success(function () {
            $(thisid).removeClass('kmmprocess').addClass('kmmprocessdone');
        });
    }
});