/**
 * Mass/Bulk update products, categories and customers
 *
 * Mass Management - PrestaShop Mass Edit Module by Kahanit(http://www.kahanit.com)
 * is licensed under a Creative Creative Commons Attribution-NoDerivatives 4.0
 * International License. Based on a work at http://www.kahanit.com.
 * Permissions beyond the scope of this license may be available at http://www.kahanit.com.
 * To view a copy of this license, visit http://creativecommons.org/licenses/by-nd/4.0/.
 *
 * @author    Amit Sidhpura <amit@kahanit.com>
 * @copyright 2015 Kahanit
 * @license   http://creativecommons.org/licenses/by-nd/4.0/
 */

$(function () {
    var ajaxURL = mm_customers_url + '&id_lang=' + default_language + '&id_shop=' + default_shop;

    var allgroups = new Bloodhound({
        datumTokenizer: Bloodhound.tokenizers.obj.whitespace('name'),
        queryTokenizer: Bloodhound.tokenizers.whitespace,
        prefetch: {
            url: ajaxURL + '&app=admin/customers/getAllGroups',
            filter: function (list) {
                return $.map(list, function (group) {
                    return {name: group};
                });
            }
        }
    });

    allgroups.clearPrefetchCache();
    allgroups.initialize();

    var displayLength = parseInt($('#customer_length').val());
    displayLength = isNaN(displayLength) ? 25 : displayLength;

    var customerTable = $('.customerTable').dataTable({
        "processing": true,
        "serverSide": true,
        "iDisplayLength": displayLength,
        "ajax": {
            "url": ajaxURL + "&app=admin/customers/populateCustomersToDT"
        },
        "columns": [
            {"data": "id_customer", "width": "30px"},
            {"data": "firstname", "width": "12%"},
            {"data": "lastname", "width": "12%"},
            {"data": "email"},
            {"data": "group", "width": "50%", "bSortable": false}
        ],
        "order": [[0, "asc"]],
        "pagingType": "full_numbers",
        "bLengthChange": false,
        "columnDefs": [
            {
                "render": function (data, type, row) {
                    return '<input data-id_customer="' + row.id + '" class="form-control text-customergroups" value="' + row.group + '">';
                },
                "targets": 4
            }
        ],
        "createdRow": function (row, data) {
            $(row).attr('data-id_customer', data.id);
        }
    }).on('draw.dt', function () {
        $('.text-customergroups').tagsinput({
            typeaheadjs: {
                name: 'text-customergroups',
                displayKey: 'name',
                valueKey: 'name',
                source: allgroups.ttAdapter()
            },
            freeInput: false
        });

        $('.text-customergroups').on('itemAdded', function (tag) {
            var thisnext = $(this).next();
            thisnext.removeClass('kmmprocessdone').addClass('kmmprocess');

            $.ajax({
                url: ajaxURL + '&app=admin/customers/ajaxManageGroupToCustomer',
                type: 'POST',
                data: {tagAction: 1, tag: tag.item, id_customer: $(this).data('id_customer')}
            }).success(function () {
                thisnext.removeClass('kmmprocess').addClass('kmmprocessdone');
            });
        });

        $('.text-customergroups').on('itemRemoved', function (tag) {
            var thisnext = $(this).next();
            thisnext.removeClass('kmmprocessdone').addClass('kmmprocess');

            $.ajax({
                url: ajaxURL + '&app=admin/customers/ajaxManageGroupToCustomer',
                type: 'POST',
                data: {tagAction: 0, tag: tag.item, id_customer: $(this).data('id_customer')}
            }).success(function () {
                thisnext.removeClass('kmmprocess').addClass('kmmprocessdone');
            });

        });
    });

    $('#customer_reload').click(function () {
        customerTable.api().ajax.reload();
    });

    $('#customer_length').keyup(function (e) {
        if (e.keyCode == 13) {
            var newLength = parseInt($('#customer_length').val());
            newLength = isNaN(newLength) ? 25 : newLength;

            customerTable.fnSettings()._iDisplayLength = newLength;
            customerTable.fnDraw();
        }
    });

    $('#customer_search').keyup(function (e) {
        if (e.keyCode == 13)
            customerTable.fnFilter($(this).val());
    });
});