/**
 * Mass/Bulk update products, categories and customers
 *
 * Mass Management - PrestaShop Mass Edit Module by Kahanit(http://www.kahanit.com)
 * is licensed under a Creative Creative Commons Attribution-NoDerivatives 4.0
 * International License. Based on a work at http://www.kahanit.com.
 * Permissions beyond the scope of this license may be available at http://www.kahanit.com.
 * To view a copy of this license, visit http://creativecommons.org/licenses/by-nd/4.0/.
 *
 * @author    Amit Sidhpura <amit@kahanit.com>
 * @copyright 2015 Kahanit
 * @license   http://creativecommons.org/licenses/by-nd/4.0/
 */

$(function () {
    var ajaxURL = mm_products_url + '&id_lang=' + default_language + '&id_shop=' + default_shop;

    var displayLength = parseInt($('#product_length').val());
    displayLength = isNaN(displayLength) ? 25 : displayLength;

    var allSuppliers = new Bloodhound({
        datumTokenizer: Bloodhound.tokenizers.obj.whitespace('supplier'),
        queryTokenizer: Bloodhound.tokenizers.whitespace,
        prefetch: {
            url: ajaxURL + '&app=admin/products/getAllSupplier',
            filter: function (list) {
                return $.map(list, function (group) {

                    return {supplier: group};
                });
            }
        }
    });
    allSuppliers.clearPrefetchCache();
    allSuppliers.initialize();

    var productTable = $('.productTable').dataTable({
        "processing": true,
        "serverSide": true,
        "iDisplayLength": displayLength,
        "ajax": {
            "url": ajaxURL + '&app=admin/products/populateProductsToDT'
        },
        "columns": [
            {"data": "id_product", "width": "30px"},
            {"data": "name"},
            {"width": "50%", "bSortable": false}
        ],
        "order": [[0, "asc"]],
        "pagingType": "full_numbers",
        "bLengthChange": false,
        "columnDefs": [
            {
                "render": function (data, type, row) {
                    return row.name[default_language];
                },
                "targets": 1
            },
            {
                "render": function (data, type, row) {
                    var entity = productTable.data('entity');

                    switch (entity) {
                        case 'name':
                        case 'meta_title':
                        case 'meta_description':
                        case 'meta_keywords':
                        case 'link_rewrite':
                        case 'tags':
                            $tmp = '';
                            jQuery.each((eval("row." + entity)), function (index, value) {
                                $tmp = $tmp + '<div class="row translatable-field lang-' + index + '">\
									<div class="col-lg-10">\
										<input type="text" id="product-name-' + index + '-' + row.id +
                                    '" data-id_lang="' + index + '" data-metafield="' + entity +
                                    '" class="form-control product-' + entity + '" data-id_product="' + row.id +
                                    '" value="' + value + '">\
									</div>\
									' + languageDropdown(lang_data, lang_data[index]['iso_code']) + '\
								</div>';
                            });
                            return $tmp;
                            break;
                        case 'manufacturer':
                            return '<select data-id_product="' + row.id + '" class="kmm_manufacturer" id="kmm_manufacturer-' + row.id + '">' +
                                row.manufacturer +
                                '</select>';
                            break;
                        case 'suppliers':
                            return '<input id="" type="text" value="' + row.suppliers + '" class="form-control product-' + entity +
                                '" data-id_product="' + row.id + '" /><select data-id_product="' + row.id +
                                '" class="kmm_supplier" id="kmm_supplier-' + row.id + '">' + row.suplierDD + '</select>';
                            break;
                        default:
                            break;
                    }

                },
                "targets": 2
            }
        ]
    }).on('draw.dt', function () {
        mmHideOtherLanguage(default_language);
        var entity = (productTable).data('entity');

        switch (entity) {
            case 'name':
            case 'meta_title':
            case 'meta_description':
            case 'meta_keywords':
            case 'link_rewrite':
                $('.product-' + entity).on('change', updateProductMetaField);
                break;
            case 'tags':
                $('.product-' + entity).tagsinput();

                $('.product-' + entity).on('itemAdded', function (tag) {
                    var thisnext = $(this).next();
                    thisnext.removeClass('kmmprocessdone').addClass('kmmprocess');

                    $.ajax({
                        url: ajaxURL + '&app=admin/products/ajaxAddRemoveProductTag',
                        type: 'POST',
                        data: {
                            productTagAction: 1,
                            tag: tag.item,
                            id_product: $(this).data('id_product'),
                            lang_id: $(this).data('id_lang')
                        }
                    }).success(function () {
                        thisnext.removeClass('kmmprocess').addClass('kmmprocessdone');
                    });
                });

                $('.product-' + entity).on('itemRemoved', function (tag) {
                    var thisnext = $(this).next();
                    thisnext.removeClass('kmmprocessdone').addClass('kmmprocess');

                    $.ajax({
                        url: ajaxURL + '&app=admin/products/ajaxAddRemoveProductTag',
                        type: 'POST',
                        data: {
                            productTagAction: 0,
                            tag: tag.item,
                            id_product: $(this).data('id_product'),
                            lang_id: $(this).data('id_lang')
                        }
                    }).success(function () {
                        thisnext.removeClass('kmmprocess').addClass('kmmprocessdone');
                    });
                });
                break;
            case 'manufacturer':
                $('.kmm_manufacturer').chosen().trigger("chosen:updated").on('change', function () {
                    var thisid = '#' + $(this).attr('id');
                    var newid = thisid.replace(/-/g, '_') + '_chosen';
                    var id_manufacturer = $('option:selected', this).attr('value');

                    $(newid + ' a div').removeClass('kmmprocessdone').addClass('kmmprocess');

                    $.ajax({
                        url: ajaxURL + '&app=admin/products/ajaxUpdateManufacturer',
                        data: {id_manufacturer: id_manufacturer, id_product: $(this).data('id_product')},
                        type: 'POST'
                    }).success(function () {
                        $(newid + ' a div').removeClass('kmmprocess').addClass('kmmprocessdone');
                    });
                });
                break;
            case 'suppliers':
                $('.product-' + entity).tagsinput({
                    typeaheadjs: {
                        name: 'product-' + entity,
                        displayKey: 'supplier',
                        valueKey: 'supplier',
                        source: allSuppliers.ttAdapter()
                    },
                    freeInput: false
                });

                $('.product-' + entity).on('itemAdded', function (tag) {
                    var thisnext = $(this).next();
                    thisnext.removeClass('kmmprocessdone').addClass('kmmprocess');

                    $.ajax({
                        url: ajaxURL + '&app=admin/products/addRemoveProductSupplier',
                        type: 'POST',
                        data: {
                            productSupplierAction: 1,
                            supplier: tag.item,
                            id_product: $(this).data('id_product')
                        }
                    }).success(function () {
                        thisnext.removeClass('kmmprocess').addClass('kmmprocessdone');
                    });
                });

                $('.product-' + entity).on('itemRemoved', function (tag) {
                    var thisnext = $(this).next();
                    thisnext.removeClass('kmmprocessdone').addClass('kmmprocess');

                    $.ajax({
                        url: ajaxURL + '&app=admin/products/addRemoveProductSupplier',
                        type: 'POST',
                        data: {
                            productSupplierAction: 0,
                            supplier: tag.item,
                            id_product: $(this).data('id_product')
                        }
                    }).success(function () {
                        thisnext.removeClass('kmmprocess').addClass('kmmprocessdone');
                    });
                });

                $('.kmm_supplier').chosen().trigger("chosen:updated").on('change', function () {
                    var thisid = '#' + $(this).attr('id');
                    var newid = thisid.replace(/-/g, '_') + '_chosen';
                    var id_supplier = $('option:selected', this).attr('value');

                    $(newid + ' a div').removeClass('kmmprocessdone').addClass('kmmprocess');

                    $.ajax({
                        url: ajaxURL + '&app=admin/products/updateDefaultSupplier',
                        data: {id_supplier: id_supplier, id_product: $(this).data('id_product')},
                        type: 'POST'
                    }).success(function () {
                        $(newid + ' a div').removeClass('kmmprocess').addClass('kmmprocessdone');
                    });
                });
                break;
            default:
                break;
        }
    });

    $('#product_reload').click(function () {
        productTable.api().ajax.reload();
    });

    $('#product_length').keyup(function (e) {
        if (e.keyCode == 13) {
            var newLength = parseInt($('#product_length').val());
            newLength = isNaN(newLength) ? 25 : newLength;

            productTable.fnSettings()._iDisplayLength = newLength;
            productTable.fnDraw();
        }
    });

    $('#product_search').keyup(function (e) {
        if (e.keyCode == 13)
            productTable.fnFilter($(this).val());
    });

    function languageDropdown(languageArray, currentLanguageISO) {
        var count = 0;
        var rtn = '<div class="col-lg-2">\
			<button type="button" class="btn btn-default dropdown-toggle" tabindex="-1" data-toggle="dropdown">\
				' + currentLanguageISO + ' <span class="caret"></span>\
			</button>\
			<ul class="dropdown-menu">'
        jQuery.each(languageArray, function (index) {
            rtn = rtn + '<li>\
				<a href="javascript:mmHideOtherLanguage(' + index + ');" tabindex="-1" rollapp-href="javascript:mmHideOtherLanguage(1);">\
				' + languageArray[index]['name'] + '\
				</a>\
			</li>';
            count = count + 1;
        });
        if (count < 2)
            return '';
        return rtn + '</ul>\
		</div>';
    }

    function updateProductMetaField() {
        var id_product = $(this).data('id_product');
        var id_lang = $(this).data('id_lang');
        var productmetafield = $(this).data('metafield');
        var thisid = '#' + $(this).attr('id');

        $(this).removeClass('kmmprocessdone').addClass('kmmprocess');

        $.ajax({
            url: ajaxURL + '&app=admin/products/ajaxUpdateMetaField&flag=updateproductmetakey',
            type: 'POST',
            data: {
                lang_id: id_lang,
                id_product: id_product,
                productmetafield: productmetafield,
                metavalue: $(this).val()
            }
        }).success(function (data) {
            $(thisid).removeClass('kmmprocess').addClass('kmmprocessdone');
            console.log(data);
        });
    }
});